[![Build Status](https://travis-ci.com/hungpham2017/mcu.svg?branch=master)](https://travis-ci.com/hungpham2017/mcu)
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)
![GitHub last commit](https://img.shields.io/github/last-commit/hungpham2017/mcu.svg?color=gold)
![GitHub issues](https://img.shields.io/github/issues-raw/hungpham2017/mcu.svg?color=crimson)
<!-- ![Codecov](https://img.shields.io/codecov/c/github/hungpham2017/mcu.svg?color=crimson) -->

# Modeling and Crystallographic Utilities (mcu)
MCU is a comprehensive package for the analysis of periodic wavefunctions and crystallography. It is specifically designed to facilitate large-scale analysis and provide topological descriptions for periodic wavefunctions.

<img src="https://github.com/hungpham2017/mcu/blob/gh-pages/docs/image/quicklook.png" width="800" align="middle">

# Installation

```
conda install -c hqp mcu
```

## Features:
- MCU provides support for various major periodic electronic structure codes, including [VASP](https://www.vasp.at/), [Quantum Espresso](https://www.quantum-espresso.org/), [CRYSTAL](https://www.crystal.unito.it/), [CP2K(https://www.cp2k.org/)], and [Wannier90](http://www.wannier.org/).
- It offers a flexible syntax for orbital selection, making it easy to plot projected band structures and density of states (DOS).
- MCU also provides a convenient method for selecting orbitals and generating input (d3) files for CRYSTAL calculations. Projected DOS analysis using CRYSTAL has never been easier.

## Documentation:
-  Installation and tutorials can be found [here](https://hungqpham.com/mcu/)

## Authors
- **Hung Pham**

## Contributing
Contributions are welcome! If you encounter any issues or have suggestions for improvements, please open an issue or submit a pull request. For major changes, please open an issue to discuss your ideas before proceeding.

## License
This project is licensed under the Apache License - see the [LICENSE](LICENSE) file for details

## Acknowledgments
We would like to thank the contributors and the open-source community for their valuable contributions and support.

## References
If you find **mcu** useful for your research, please consider citing the following:

```
Pham, H. Q. MCU: Modeling and Crystallographic Utilities,
2021 https://github.com/hungpham2017/mcu (accessed Jan, 18,
2021).
```